==> openshift-model-config-6.2.0-sources.jar: io/fabric8/openshift/api/model/config/v1/InfrastructureStatusFluentImpl.java <==
package io.fabric8.openshift.api.model.config.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class InfrastructureStatusFluentImpl<A extends InfrastructureStatusFluent<A>> extends BaseFluent<A> implements InfrastructureStatusFluent<A>{
  public InfrastructureStatusFluentImpl() {
  }
  public InfrastructureStatusFluentImpl(InfrastructureStatus instance) {
    this.withApiServerInternalURI(instance.getApiServerInternalURI()); 
    this.withApiServerURL(instance.getApiServerURL()); 
    this.withControlPlaneTopology(instance.getControlPlaneTopology()); 
    this.withEtcdDiscoveryDomain(instance.getEtcdDiscoveryDomain()); 
    this.withInfrastructureName(instance.getInfrastructureName()); 
    this.withInfrastructureTopology(instance.getInfrastructureTopology()); 
    this.withPlatform(instance.getPlatform()); 
    this.withPlatformStatus(instance.getPlatformStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private String apiServerInternalURI;
  private String apiServerURL;
  private String controlPlaneTopology;
  private String etcdDiscoveryDomain;
  private String infrastructureName;
  private String infrastructureTopology;
  private String platform;
  private PlatformStatusBuilder platformStatus;
  private Map<String,Object> additionalProperties;
  public String getApiServerInternalURI() {
    return this.apiServerInternalURI;
  }
  public A withApiServerInternalURI(String apiServerInternalURI) {
    this.apiServerInternalURI=apiServerInternalURI; return (A) this;
  }
  public Boolean hasApiServerInternalURI() {
    return this.apiServerInternalURI != null;
  }
  public String getApiServerURL() {
    return this.apiServerURL;
  }
  public A withApiServerURL(String apiServerURL) {
    this.apiServerURL=apiServerURL; return (A) this;
  }
  public Boolean hasApiServerURL() {
    return this.apiServerURL != null;
  }
  public String getControlPlaneTopology() {
    return this.controlPlaneTopology;
  }
  public A withControlPlaneTopology(String controlPlaneTopology) {
    this.controlPlaneTopology=controlPlaneTopology; return (A) this;
  }
  public Boolean hasControlPlaneTopology() {
    return this.controlPlaneTopology != null;
  }
  public String getEtcdDiscoveryDomain() {
    return this.etcdDiscoveryDomain;
  }
  public A withEtcdDiscoveryDomain(String etcdDiscoveryDomain) {
    this.etcdDiscoveryDomain=etcdDiscoveryDomain; return (A) this;
  }
  public Boolean hasEtcdDiscoveryDomain() {
    return this.etcdDiscoveryDomain != null;
  }
  public String getInfrastructureName() {
    return this.infrastructureName;
  }
  public A withInfrastructureName(String infrastructureName) {
    this.infrastructureName=infrastructureName; return (A) this;
  }
  public Boolean hasInfrastructureName() {
    return this.infrastructureName != null;
  }
  public String getInfrastructureTopology() {
    return this.infrastructureTopology;
  }
  public A withInfrastructureTopology(String infrastructureTopology) {
    this.infrastructureTopology=infrastructureTopology; return (A) this;
  }
  public Boolean hasInfrastructureTopology() {
    return this.infrastructureTopology != null;
  }
  public String getPlatform() {
    return this.platform;
  }
  public A withPlatform(String platform) {
    this.platform=platform; return (A) this;
  }
  public Boolean hasPlatform() {
    return this.platform != null;
  }
  
  /**
   * This method has been deprecated, please use method buildPlatformStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public PlatformStatus getPlatformStatus() {
    return this.platformStatus!=null ?this.platformStatus.build():null;
  }
  public PlatformStatus buildPlatformStatus() {
    return this.platformStatus!=null ?this.platformStatus.build():null;
  }
  public A withPlatformStatus(PlatformStatus platformStatus) {
    _visitables.get("platformStatus").remove(this.platformStatus);
    if (platformStatus!=null){ this.platformStatus= new PlatformStatusBuilder(platformStatus); _visitables.get("platformStatus").add(this.platformStatus);} else { this.platformStatus = null; _visitables.get("platformStatus").remove(this.platformStatus); } return (A) this;
  }
  public Boolean hasPlatformStatus() {
    return this.platformStatus != null;
  }
  public InfrastructureStatusFluent.PlatformStatusNested<A> withNewPlatformStatus() {
    return new InfrastructureStatusFluentImpl.PlatformStatusNestedImpl();
  }
  public InfrastructureStatusFluent.PlatformStatusNested<A> withNewPlatformStatusLike(PlatformStatus item) {
    return new InfrastructureStatusFluentImpl.PlatformStatusNestedImpl(item);
  }
  public InfrastructureStatusFluent.PlatformStatusNested<A> editPlatformStatus() {
    return withNewPlatformStatusLike(getPlatformStatus());
  }
  public InfrastructureStatusFluent.PlatformStatusNested<A> editOrNewPlatformStatus() {
    return withNewPlatformStatusLike(getPlatformStatus() != null ? getPlatformStatus(): new PlatformStatusBuilder().build());
  }
  public InfrastructureStatusFluent.PlatformStatusNested<A> editOrNewPlatformStatusLike(PlatformStatus item) {
    return withNewPlatformStatusLike(getPlatformStatus() != null ? getPlatformStatus(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    InfrastructureStatusFluentImpl that = (InfrastructureStatusFluentImpl) o;
    if (apiServerInternalURI != null ? !apiServerInternalURI.equals(that.apiServerInternalURI) :that.apiServerInternalURI != null) return false;
    if (apiServerURL != null ? !apiServerURL.equals(that.apiServerURL) :that.apiServerURL != null) return false;
    if (controlPlaneTopology != null ? !controlPlaneTopology.equals(that.controlPlaneTopology) :that.controlPlaneTopology != null) return false;
    if (etcdDiscoveryDomain != null ? !etcdDiscoveryDomain.equals(that.etcdDiscoveryDomain) :that.etcdDiscoveryDomain != null) return false;
    if (infrastructureName != null ? !infrastructureName.equals(that.infrastructureName) :that.infrastructureName != null) return false;
    if (infrastructureTopology != null ? !infrastructureTopology.equals(that.infrastructureTopology) :that.infrastructureTopology != null) return false;
    if (platform != null ? !platform.equals(that.platform) :that.platform != null) return false;
    if (platformStatus != null ? !platformStatus.equals(that.platformStatus) :that.platformStatus != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiServerInternalURI,  apiServerURL,  controlPlaneTopology,  etcdDiscoveryDomain,  infrastructureName,  infrastructureTopology,  platform,  platformStatus,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiServerInternalURI != null) { sb.append("apiServerInternalURI:"); sb.append(apiServerInternalURI + ","); }
    if (apiServerURL != null) { sb.append("apiServerURL:"); sb.append(apiServerURL + ","); }
    if (controlPlaneTopology != null) { sb.append("controlPlaneTopology:"); sb.append(controlPlaneTopology + ","); }
    if (etcdDiscoveryDomain != null) { sb.append("etcdDiscoveryDomain:"); sb.append(etcdDiscoveryDomain + ","); }
    if (infrastructureName != null) { sb.append("infrastructureName:"); sb.append(infrastructureName + ","); }
    if (infrastructureTopology != null) { sb.append("infrastructureTopology:"); sb.append(infrastructureTopology + ","); }
    if (platform != null) { sb.append("platform:"); sb.append(platform + ","); }
    if (platformStatus != null) { sb.append("platformStatus:"); sb.append(platformStatus + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class PlatformStatusNestedImpl<N> extends PlatformStatusFluentImpl<InfrastructureStatusFluent.PlatformStatusNested<N>> implements InfrastructureStatusFluent.PlatformStatusNested<N>,Nested<N>{
    PlatformStatusNestedImpl(PlatformStatus item) {
      this.builder = new PlatformStatusBuilder(this, item);
    }
    PlatformStatusNestedImpl() {
      this.builder = new PlatformStatusBuilder(this);
    }
    PlatformStatusBuilder builder;
    public N and() {
      return (N) InfrastructureStatusFluentImpl.this.withPlatformStatus(builder.build());
    }
    public N endPlatformStatus() {
      return and();
    }
    
  }
  
}

==> openshift-model-config-6.7.0-sources.jar: io/fabric8/openshift/api/model/config/v1/InfrastructureStatusFluentImpl.java <==
package io.fabric8.openshift.api.model.config.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class InfrastructureStatusFluentImpl<A extends InfrastructureStatusFluent<A>> extends BaseFluent<A> implements InfrastructureStatusFluent<A>{
  public InfrastructureStatusFluentImpl() {
  }
  public InfrastructureStatusFluentImpl(InfrastructureStatus instance) {
    if (instance != null) {
      this.withApiServerInternalURI(instance.getApiServerInternalURI());
      this.withApiServerURL(instance.getApiServerURL());
      this.withControlPlaneTopology(instance.getControlPlaneTopology());
      this.withEtcdDiscoveryDomain(instance.getEtcdDiscoveryDomain());
      this.withInfrastructureName(instance.getInfrastructureName());
      this.withInfrastructureTopology(instance.getInfrastructureTopology());
      this.withPlatform(instance.getPlatform());
      this.withPlatformStatus(instance.getPlatformStatus());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private String apiServerInternalURI;
  private String apiServerURL;
  private String controlPlaneTopology;
  private String etcdDiscoveryDomain;
  private String infrastructureName;
  private String infrastructureTopology;
  private String platform;
  private PlatformStatusBuilder platformStatus;
  private Map<String,Object> additionalProperties;
  public String getApiServerInternalURI() {
    return this.apiServerInternalURI;
  }
  public A withApiServerInternalURI(String apiServerInternalURI) {
    this.apiServerInternalURI=apiServerInternalURI; return (A) this;
  }
  public Boolean hasApiServerInternalURI() {
    return this.apiServerInternalURI != null;
  }
  public String getApiServerURL() {
    return this.apiServerURL;
  }
  public A withApiServerURL(String apiServerURL) {
    this.apiServerURL=apiServerURL; return (A) this;
  }
  public Boolean hasApiServerURL() {
    return this.apiServerURL != null;
  }
  public String getControlPlaneTopology() {
    return this.controlPlaneTopology;
  }
  public A withControlPlaneTopology(String controlPlaneTopology) {
    this.controlPlaneTopology=controlPlaneTopology; return (A) this;
  }
  public Boolean hasControlPlaneTopology() {
    return this.controlPlaneTopology != null;
  }
  public String getEtcdDiscoveryDomain() {
    return this.etcdDiscoveryDomain;
  }
  public A withEtcdDiscoveryDomain(String etcdDiscoveryDomain) {
    this.etcdDiscoveryDomain=etcdDiscoveryDomain; return (A) this;
  }
  public Boolean hasEtcdDiscoveryDomain() {
    return this.etcdDiscoveryDomain != null;
  }
  public String getInfrastructureName() {
    return this.infrastructureName;
  }
  public A withInfrastructureName(String infrastructureName) {
    this.infrastructureName=infrastructureName; return (A) this;
  }
  public Boolean hasInfrastructureName() {
    return this.infrastructureName != null;
  }
  public String getInfrastructureTopology() {
    return this.infrastructureTopology;
  }
  public A withInfrastructureTopology(String infrastructureTopology) {
    this.infrastructureTopology=infrastructureTopology; return (A) this;
  }
  public Boolean hasInfrastructureTopology() {
    return this.infrastructureTopology != null;
  }
  public String getPlatform() {
    return this.platform;
  }
  public A withPlatform(String platform) {
    this.platform=platform; return (A) this;
  }
  public Boolean hasPlatform() {
    return this.platform != null;
  }
  
  /**
   * This method has been deprecated, please use method buildPlatformStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public PlatformStatus getPlatformStatus() {
    return this.platformStatus!=null ?this.platformStatus.build():null;
  }
  public PlatformStatus buildPlatformStatus() {
    return this.platformStatus!=null ?this.platformStatus.build():null;
  }
  public A withPlatformStatus(PlatformStatus platformStatus) {
    _visitables.get("platformStatus").remove(this.platformStatus);
    if (platformStatus!=null){ this.platformStatus= new PlatformStatusBuilder(platformStatus); _visitables.get("platformStatus").add(this.platformStatus);} else { this.platformStatus = null; _visitables.get("platformStatus").remove(this.platformStatus); } return (A) this;
  }
  public Boolean hasPlatformStatus() {
    return this.platformStatus != null;
  }
  public InfrastructureStatusFluentImpl.PlatformStatusNested<A> withNewPlatformStatus() {
    return new InfrastructureStatusFluentImpl.PlatformStatusNestedImpl();
  }
  public InfrastructureStatusFluentImpl.PlatformStatusNested<A> withNewPlatformStatusLike(PlatformStatus item) {
    return new InfrastructureStatusFluentImpl.PlatformStatusNestedImpl(item);
  }
  public InfrastructureStatusFluentImpl.PlatformStatusNested<A> editPlatformStatus() {
    return withNewPlatformStatusLike(getPlatformStatus());
  }
  public InfrastructureStatusFluentImpl.PlatformStatusNested<A> editOrNewPlatformStatus() {
    return withNewPlatformStatusLike(getPlatformStatus() != null ? getPlatformStatus(): new PlatformStatusBuilder().build());
  }
  public InfrastructureStatusFluentImpl.PlatformStatusNested<A> editOrNewPlatformStatusLike(PlatformStatus item) {
    return withNewPlatformStatusLike(getPlatformStatus() != null ? getPlatformStatus(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    InfrastructureStatusFluentImpl that = (InfrastructureStatusFluentImpl) o;
    if (!java.util.Objects.equals(apiServerInternalURI, that.apiServerInternalURI)) return false;

    if (!java.util.Objects.equals(apiServerURL, that.apiServerURL)) return false;

    if (!java.util.Objects.equals(controlPlaneTopology, that.controlPlaneTopology)) return false;

    if (!java.util.Objects.equals(etcdDiscoveryDomain, that.etcdDiscoveryDomain)) return false;

    if (!java.util.Objects.equals(infrastructureName, that.infrastructureName)) return false;

    if (!java.util.Objects.equals(infrastructureTopology, that.infrastructureTopology)) return false;

    if (!java.util.Objects.equals(platform, that.platform)) return false;

    if (!java.util.Objects.equals(platformStatus, that.platformStatus)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiServerInternalURI,  apiServerURL,  controlPlaneTopology,  etcdDiscoveryDomain,  infrastructureName,  infrastructureTopology,  platform,  platformStatus,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiServerInternalURI != null) { sb.append("apiServerInternalURI:"); sb.append(apiServerInternalURI + ","); }
    if (apiServerURL != null) { sb.append("apiServerURL:"); sb.append(apiServerURL + ","); }
    if (controlPlaneTopology != null) { sb.append("controlPlaneTopology:"); sb.append(controlPlaneTopology + ","); }
    if (etcdDiscoveryDomain != null) { sb.append("etcdDiscoveryDomain:"); sb.append(etcdDiscoveryDomain + ","); }
    if (infrastructureName != null) { sb.append("infrastructureName:"); sb.append(infrastructureName + ","); }
    if (infrastructureTopology != null) { sb.append("infrastructureTopology:"); sb.append(infrastructureTopology + ","); }
    if (platform != null) { sb.append("platform:"); sb.append(platform + ","); }
    if (platformStatus != null) { sb.append("platformStatus:"); sb.append(platformStatus + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class PlatformStatusNestedImpl<N> extends PlatformStatusFluentImpl<InfrastructureStatusFluentImpl.PlatformStatusNested<N>> implements InfrastructureStatusFluentImpl.PlatformStatusNested<N>,Nested<N>{
    PlatformStatusNestedImpl(PlatformStatus item) {
      this.builder = new PlatformStatusBuilder(this, item);
    }
    PlatformStatusNestedImpl() {
      this.builder = new PlatformStatusBuilder(this);
    }
    PlatformStatusBuilder builder;
    public N and() {
      return (N) InfrastructureStatusFluentImpl.this.withPlatformStatus(builder.build());
    }
    public N endPlatformStatus() {
      return and();
    }
    
  }
  
}
